

LYMPHATIC:
	The cybernetic immune system hyper drive of the inter-ellipitic navigator.

	Installation:
		[tcsh] pip install LYMPHATIC

	To open the studies.
		[tcsh] LYMPHATIC STUDIES

	priorities:
		[ ] teach lymphocytes to c# h#s